summaryrefslogtreecommitdiff
path: root/sql/sql_lex.h
diff options
context:
space:
mode:
authorsasha@mysql.sashanet.com <>2000-09-16 18:31:30 -0600
committersasha@mysql.sashanet.com <>2000-09-16 18:31:30 -0600
commit037516b7a2493132955916e60e246a92754eaaaa (patch)
treebd0f71c45f8199761c5b4706c94501d0b17807eb /sql/sql_lex.h
parentf2f515e5c2733dfe95471640ff740d0f936579b9 (diff)
parentaf9e034dacf351a375fa851236efdab30afb313a (diff)
downloadmariadb-git-037516b7a2493132955916e60e246a92754eaaaa.tar.gz
resolved conflicts
Diffstat (limited to 'sql/sql_lex.h')
-rw-r--r--sql/sql_lex.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/sql/sql_lex.h b/sql/sql_lex.h
index 1047cffffe1..6ee5a4dfccb 100644
--- a/sql/sql_lex.h
+++ b/sql/sql_lex.h
@@ -126,7 +126,8 @@ typedef struct st_lex {
udf_func udf;
HA_CHECK_OPT check_opt; // check/repair options
HA_CREATE_INFO create_info;
- LEX_MASTER_INFO mi; // used by CHANGE MASTER
+ LEX_MASTER_INFO mi; // used by CHANGE MASTER
+ char* backup_dir; // used by RESTORE/BACKUP
ulong thread_id,type;
ulong options;
enum_sql_command sql_command;